# LoadConversion: Zotero import translators

Note: This document is currently under development. It will contain the following elements.

- description and filetypes covered
- example

## Links

- [RIS field names](https://en.wikipedia.org/wiki/RIS_(file_format)#Tags)
- [List of bibliographic formats supported by Zotero translators](https://www.zotero.org/support/kb/importing_standardized_formats)
